@@ -1,8 +1,9 @@
 # source("RFtest.info.R")
 
-if (file.exists("source.R")) source("source.R")
+if (EXTENDED.TESTING <- file.exists("source.R")) source("source.R")
 
 str(GetRegisterInfo(0))
+
 cat("-------------------------------------------\n")
 try(GaussRF(1:4, grid=TRUE, model="exp", param=c(1,2,3,4)))
 str(GetRegisterInfo(0))
